@@ -7,7 +7,7 @@ function(obj,var,extrapolation = c("linear", "quadratic", "both"),ylimit) {
 
   y = apply(obj$theta[[var]],2,mean)
 
-  plot(x,y,type ="p",xlim=c(-1.5,max(x)),ylim=ylimit, xlab="Magnitude of Measurement Error", ylab="Estimated Coefficient", main = substitute(paste("Extrapolation Effect on ", var)),col ="green",pch =19)
+  plot(x,y,type ="p",xlim=c(-1.5,max(x)),ylim=ylimit, xlab=substitute(paste(lambda)), ylab="Estimated Coefficient", main = substitute(paste("Extrapolation Effect on ", var)),col ="green",pch =19)
 
   new = data.frame(x = seq(-1.2,2,0.2))
   
@@ -21,6 +21,8 @@ function(obj,var,extrapolation = c("linear", "quadratic", "both"),ylimit) {
 
   points(new$x[2],fitted.l[2],col="red",pch =19)
   
+  legend("topright", "Linear Extrapolation", col="blue", lty=1)
+  
   }
   
   if( extrapolation=="quadratic"){
@@ -32,7 +34,8 @@ function(obj,var,extrapolation = c("linear", "quadratic", "both"),ylimit) {
   lines(new$x,fitted.q, col="red")
 
   points(new$x[2],fitted.q[2],col="blue",pch =19)
-
+  
+  legend("topright", "Quadratric Extrapolation", col="red", lty=1)
 
 }
 
@@ -53,6 +56,8 @@ function(obj,var,extrapolation = c("linear", "quadratic", "both"),ylimit) {
   lines(new$x,fitted.q, col="red")
 
   points(new$x[2],fitted.q[2],col="blue",pch =19)
+  
+  legend("topright", c("Linear Extrapolation", "Quadratric Extrapolation"), col=c("blue","red"), lty=1)
  
  }
 
